with_prelude

Function with_prelude 

pub fn with_prelude(body: &str) -> String
Build a full prelude string by appending the user’s shader body to the standard ShaderUniforms declaration. body is expected to already be translated to WGSL.